Changelog
=========
1.4 2018-08-13
--------------
Fixed
~~~~~
- PyBEL database is now ensured before trying to populate with a BELNamespaceManager

1.3 2018-08-08
--------------
Added
~~~~~
- Add ``add_namespace_to_graph`` function for more quickly handling
  addition of a namespace to a BEL Graph
